@@ -1,20 +1,19 @@
 from __future__ import print_function
 
+import os
 from pprint import pprint
 
+from cloudmesh.common.Host import Host
+from cloudmesh.common.Printer import Printer
+from cloudmesh.common.Shell import Shell
+from cloudmesh.common.console import Console
 from cloudmesh.common.debug import VERBOSE
 from cloudmesh.common.parameter import Parameter
-from cloudmesh.common.Host import Host
+from cloudmesh.common.util import path_expand
 # from cloudmesh.host.host import Host
 from cloudmesh.shell.command import PluginCommand
 from cloudmesh.shell.command import command
-from cloudmesh.common.util import path_expand
 from cloudmesh.shell.command import map_parameters
-import os
-from cloudmesh.common.Shell import Shell
-import sys
-from cloudmesh.common.console import Console
-from cloudmesh.common.Printer import Printer
 
 
 class HostCommand(PluginCommand):
@@ -28,7 +27,7 @@ class HostCommand(PluginCommand):
           Usage:
               host scp NAMES SOURCE DESTINATION [--dryrun]
               host ssh NAMES COMMAND [--dryrun] [--output=FORMAT]
-              host config NAMES IPS [--user=USER] [--key=PUBLIC]
+              host config NAMES [IPS] [--user=USER] [--key=PUBLIC]
               host check NAMES [--user=USER] [--key=PUBLIC]
               host key create NAMES [--user=USER] [--dryrun] [--output=FORMAT]
               host key list NAMES [--output=FORMAT]
@@ -227,8 +226,8 @@ class HostCommand(PluginCommand):
                                 username=arguments.user,
                                 key=key)
             for entry in result:
-                 entry['success'] = entry['stdout'] == entry['host']
+                entry['success'] = entry['stdout'] == entry['host']
 
-            _print (result)
+            _print(result)
 
         return ""
